<?php

if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}

if ( ! function_exists( 'cheshalo_get_vc_map_mega_menu' ) ) {
	function cheshalo_get_vc_map_mega_menu() {
		$item_typography = cheshalo_get_typography_map(
			array(
				'title'    => esc_html__( 'Typography', 'cheshalo' ),
				'key'      => 'item_typography',
				'selector' => '{{WRAPPER}} .wd-nav > .menu-item > a',
			)
		);

		return array(
			'name'        => esc_html__( 'Mega Menu widget', 'cheshalo' ),
			'base'        => 'cheshalo_mega_menu',
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'description' => esc_html__( 'Categories mega menu widget', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/mega-menu-widget.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'General options', 'cheshalo' ),
					'param_name' => 'general_divider',
				),
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Title', 'cheshalo' ),
					'param_name'       => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'vertical' ),
					),
				),
				array(
					'type'             => 'cheshalo_dropdown',
					'heading'          => esc_html__( 'Choose Menu', 'cheshalo' ),
					'param_name'       => 'nav_menu',
					'callback'         => 'cheshalo_get_menus_array',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Orientation', 'cheshalo' ),
					'param_name'       => 'design',
					'value'            => array(
						esc_html__( 'Vertical', 'cheshalo' ) => 'vertical',
						esc_html__( 'Horizontal', 'cheshalo' ) => 'horizontal',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Design', 'cheshalo' ),
					'param_name'       => 'dropdown_design',
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'With background', 'cheshalo' ) => 'with-bg',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'vertical' ),
					),
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Style', 'cheshalo' ),
					'param_name'       => 'style',
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' )    => 'default',
						esc_html__( 'Underline', 'cheshalo' )  => 'underline',
						esc_html__( 'Bordered', 'cheshalo' )   => 'bordered',
						esc_html__( 'Separated', 'cheshalo' )  => 'separated',
						esc_html__( 'Background', 'cheshalo' ) => 'bg',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'horizontal' ),
					),
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Items gap', 'cheshalo' ),
					'param_name'       => 'items_gap',
					'value'            => array(
						esc_html__( 'Small', 'cheshalo' ) => 's',
						esc_html__( 'Medium', 'cheshalo' ) => 'm',
						esc_html__( 'Large', 'cheshalo' ) => 'l',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'horizontal' ),
					),
				),
				array(
					'type'             => 'cheshalo_image_select',
					'heading'          => esc_html__( 'Alignment', 'cheshalo' ),
					'param_name'       => 'alignment',
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' )  => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value'     => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'horizontal' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				$item_typography['font_family'],
				$item_typography['font_size'],
				$item_typography['font_weight'],
				$item_typography['text_transform'],
				$item_typography['font_style'],
				$item_typography['line_height'],
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Title options', 'cheshalo' ),
					'param_name' => 'title_divider',
					'dependency' => array(
						'element' => 'design',
						'value'   => array( 'vertical' ),
					),
				),
				array(
					'type'             => 'cheshalo_button_set',
					'heading'          => esc_html__( 'Color Scheme', 'cheshalo' ),
					'param_name'       => 'cheshalo_color_scheme',
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Light', 'cheshalo' )   => 'light',
						esc_html__( 'Dark', 'cheshalo' )    => 'dark',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_colorpicker',
					'heading'          => esc_html__( 'Title background color', 'cheshalo' ),
					'param_name'       => 'color',
					'css_args'         => array(
						'background-color' => array(
							' .widget-title',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider',
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
				),
				array(
					'type'       => 'css_editor',
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'param_name' => 'css',
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
				),
				cheshalo_get_vc_responsive_spacing_map(),
				/**
				 * Advanced
				 */

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
