<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );}

/**
 * ------------------------------------------------------------------------------------------------
 *  Get categories dropdown vertical menu
 * ------------------------------------------------------------------------------------------------
 */

if ( ! class_exists( 'CHESHALO_HB_Categories' ) ) {
	class CHESHALO_HB_Categories extends CHESHALO_HB_Element {

		public function __construct() {
			parent::__construct();
			$this->template_name = 'categories';
		}

		public function map() {
			$this->args = array(
				'type'            => 'categories',
				'title'           => esc_html__( 'Categories', 'cheshalo' ),
				'text'            => esc_html__( 'Categories dropdown', 'cheshalo' ),
				'icon'            => 'xts-i-dropdown',
				'editable'        => true,
				'container'       => false,
				'edit_on_create'  => true,
				'drag_target_for' => array(),
				'drag_source'     => 'content_element',
				'removable'       => true,
				'addable'         => true,
				'desktop'         => true,
				'params'          => array(
					'menu_id'               => array(
						'id'          => 'menu_id',
						'title'       => esc_html__( 'Choose menu', 'cheshalo' ),
						'type'        => 'select',
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Menu', 'cheshalo' ),
						'value'       => '',
						'callback'    => 'get_menu_options_with_empty',
						'description' => esc_html__( 'Choose which menu to display in the header as a categories dropdown.', 'cheshalo' ),
					),
					'categories_title'      => array(
						'id'          => 'categories_title',
						'title'       => esc_html__( 'Menu title', 'cheshalo' ),
						'type'        => 'text',
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Menu', 'cheshalo' ),
						'value'       => '',
						'description' => esc_html__( 'Specify your custom title for this menu dropdown or leave it empty to keep "Browse categories".', 'cheshalo' ),
					),
					'more_cat_button'       => array(
						'id'          => 'more_cat_button',
						'title'       => esc_html__( 'Limit categories', 'cheshalo' ),
						'hint'        => '<video src="' . CHESHALO_TOOLTIP_URL . 'hb_categories_more_cat_button.mp4" autoplay loop muted></video>',
						'type'        => 'switcher',
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Dropdown', 'cheshalo' ),
						'value'       => false,
						'description' => __( 'Display a certain number of categories and "show more" button.', 'cheshalo' ),
					),
					'more_cat_button_count' => array(
						'id'          => 'more_cat_button_count',
						'title'       => esc_html__( 'Number of categories', 'cheshalo' ),
						'description' => esc_html__( 'Specify the number of categories to be shown initially', 'cheshalo' ),
						'type'        => 'slider',
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Dropdown', 'cheshalo' ),
						'from'        => 1,
						'to'          => 100,
						'value'       => 5,
						'units'       => '',
						'requires'    => array(
							'more_cat_button' => array(
								'comparison' => 'equal',
								'value'      => true,
							),
						),
					),
					'mouse_event'           => array(
						'id'      => 'mouse_event',
						'title'   => esc_html__( 'Open on mouse event', 'cheshalo' ),
						'type'    => 'selector',
						'tab'     => esc_html__( 'General', 'cheshalo' ),
						'group'   => esc_html__( 'Dropdown', 'cheshalo' ),
						'value'   => 'hover',
						'options' => array(
							'hover' => array(
								'value' => 'hover',
								'label' => esc_html__( 'Hover', 'cheshalo' ),
							),
							'click' => array(
								'value' => 'click',
								'label' => esc_html__( 'Click', 'cheshalo' ),
							),
						),
					),
					'open_dropdown'         => array(
						'id'          => 'open_dropdown',
						'title'       => esc_html__( 'Open menu item dropdown', 'cheshalo' ),
						'hint'        => '<video src="' . CHESHALO_TOOLTIP_URL . 'hb_categories_open_dropdown.mp4" autoplay loop muted></video>',
						'description' => __( 'Submenu dropdown stays open after cursor leaves the parent menu item. Stops working if "Open categories menu" options is enabled on a page.', 'cheshalo' ),
						'type'        => 'switcher',
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Dropdown', 'cheshalo' ),
						'value'       => false,
					),
					'design'                => array(
						'id'      => 'design',
						'title'   => esc_html__( 'Dropdown design', 'cheshalo' ),
						'type'    => 'selector',
						'tab'     => esc_html__( 'Style', 'cheshalo' ),
						'group'   => esc_html__( 'Dropdown', 'cheshalo' ),
						'value'   => 'default',
						'options' => array(
							'default' => array(
								'label' => esc_html__( 'Default', 'cheshalo' ),
								'hint'   => '<img src="' . CHESHALO_TOOLTIP_URL . 'hb_categories_design_default.jpg" alt="">',
								'value' => 'default',
							),
							'with-bg' => array(
								'label' => esc_html__( 'With background', 'cheshalo' ),
								'hint'   => '<img src="' . CHESHALO_TOOLTIP_URL . 'hb_categories_design_with_bg.jpg" alt="">',
								'value' => 'with-bg',
							),
						),
					),
					'bg_overlay'            => array(
						'id'          => 'bg_overlay',
						'title'       => esc_html__( 'Background overlay', 'cheshalo' ),
						'hint'        => '<video src="' . CHESHALO_TOOLTIP_URL . 'hb_categories_bg_overlay.mp4" autoplay loop muted></video>',
						'description' => __( 'Highlight dropdowns by darkening the background behind.', 'cheshalo' ),
						'type'        => 'switcher',
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Dropdown', 'cheshalo' ),
						'value'       => false,
					),
					'color_scheme'          => array(
						'id'          => 'color_scheme',
						'title'       => esc_html__( 'Text color scheme', 'cheshalo' ),
						'type'        => 'selector',
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Menu title', 'cheshalo' ),
						'value'       => 'light',
						'options'     => array(
							'dark'  => array(
								'value' => 'dark',
								'label' => esc_html__( 'Dark', 'cheshalo' ),
							),
							'light' => array(
								'value' => 'light',
								'label' => esc_html__( 'Light', 'cheshalo' ),
							),
						),
						'description' => esc_html__( 'Select different text color scheme depending on your header background.', 'cheshalo' ),
					),
					'background'            => array(
						'id'          => 'background',
						'type'        => 'bg',
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Menu title', 'cheshalo' ),
						'value'       => '',
						'description' => '',
					),
					'border'                => array(
						'id'              => 'border',
						'type'            => 'border',
						'sides'           => array( 'bottom', 'top', 'left', 'right' ),
						'tab'             => esc_html__( 'Style', 'cheshalo' ),
						'group'           => esc_html__( 'Menu title', 'cheshalo' ),
						'colorpicker_top' => true,
						'container'       => false,
						'value'           => '',
						'description'     => esc_html__( 'Border settings for menu title.', 'cheshalo' ),
					),
					'icon_type'             => array(
						'id'          => 'icon_type',
						'title'       => esc_html__( 'Icon type', 'cheshalo' ),
						'type'        => 'selector',
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Menu title', 'cheshalo' ),
						'value'       => 'default',
						'options'     => array(
							'default' => array(
								'value' => 'default',
								'label' => esc_html__( 'Default', 'cheshalo' ),
								'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/default-icons/burger-default.jpg',
							),
							'custom'  => array(
								'value' => 'custom',
								'label' => esc_html__( 'Custom', 'cheshalo' ),
								'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/upload.jpg',
							),
						),
						'extra_class' => 'xts-col-6',
					),
					'custom_icon'           => array(
						'id'          => 'custom_icon',
						'title'       => esc_html__( 'Upload an image', 'cheshalo' ),
						'type'        => 'image',
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Menu title', 'cheshalo' ),
						'value'       => '',
						'description' => '',
						'requires'    => array(
							'icon_type' => array(
								'comparison' => 'equal',
								'value'      => 'custom',
							),
						),
						'extra_class' => 'xts-col-6',
					),
				),
			);
		}

	}

}
