<?php
/**
 * Countdown map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_single_product_countdown' ) ) {
	/**
	 * Countdown map.
	 */
	function cheshalo_get_vc_map_single_product_countdown() {
		$typography = cheshalo_get_typography_map(
			array(
				'key'      => 'title',
				'selector' => '{{WRAPPER}}.wd-single-countdown .element-title',
			)
		);

		return array(
			'base'        => 'cheshalo_single_product_countdown',
			'name'        => esc_html__( 'Product countdown', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Single product elements', 'cheshalo' ), 'single_product' ),
			'description' => esc_html__( 'Sale price end date countdown', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/sp-icons/sp-countdown.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				array(
					'title'      => esc_html__( 'Title', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'title_divider',
				),

				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Element title', 'cheshalo' ),
					'param_name' => 'title',
				),

				array(
					'heading'          => esc_html__( 'Color', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'title_color',
					'selectors'        => array(
						'{{WRAPPER}}.wd-single-countdown .element-title' => array(
							'color: {{VALUE}};',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				$typography['font_family'],
				$typography['font_size'],
				$typography['font_weight'],
				$typography['text_transform'],
				$typography['font_style'],
				$typography['line_height'],

				array(
					'title'      => esc_html__( 'Layout', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'settings_divider',
				),

				array(
					'heading'          => esc_html__( 'Alignment', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'alignment',
					'style'            => 'images',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'left',
						),
					),
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' )   => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' )  => 'right',
					),
					'images'           => array(
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
